import { ComponentHarness, ContentContainerComponentHarness, HarnessLoader, HarnessQuery } from '@angular/cdk/testing';
/**
 * Provides some shorthand utilities that component harnesses may want.
 */
export declare class ComponentHarnessSuperclass extends ContentContainerComponentHarness {
    /**
     * Searches for an instance of the component corresponding to the given harness type under the document root element, and returns a {@link ComponentHarness} for that instance. If multiple matching components are found, a harness for the first one is returned. If no matching component is found, an error is thrown.
     */
    protected getTopLevelHarness<T extends ComponentHarness>(predicate: HarnessQuery<T>): Promise<T>;
    /**
     * Searches for all instances of the component corresponding to the given harness type under the document root element, and returns a list {@link ComponentHarness} for each instance.
     */
    protected getAllTopLevelHarnesses<T extends ComponentHarness>(predicate: HarnessQuery<T>): Promise<T[]>;
    /**
     * Gets a {@link HarnessLoader} for the document root element. This loader can be used for elements that a component creates outside its own root element (e.g. by appending to document.body).
     */
    protected getTopLevelLoader(): Promise<HarnessLoader>;
}
