import { TestScheduler } from 'rxjs/testing';
declare global {
    interface SymbolConstructor {
        readonly observable: symbol;
    }
}
type Run = Parameters<TestScheduler['run']>[0];
type Helpers = Parameters<Run>[0];
type Callback<T> = (testHelpers: Helpers & {
    testScheduler: TestScheduler;
}) => T;
/**
 * A helper to take some boilerplate out of RxJS's {@link https://rxjs-dev.firebaseapp.com/guide/testing/marble-testing marble testing} API.
 *
 * ```ts
 * it("doubles numbers", marbleTest(({ cold, expectObservable }) => {
 *   const source = cold("-1-2-3-|");
 *   const expected = "   -2-4-6-|");
 *   expectObservable(source.pipe(double())).toBe(expected);
 * }));
 * ```
 */
export declare function marbleTest<T>(callback: Callback<T>): () => T;
export {};
