import { TestRequest } from '@angular/common/http/testing';
import { SlTestRequest } from './sl-test-request';
export type HttpMethod = 'DELETE' | 'GET' | 'POST' | 'PUT';
export type HttpBody = Parameters<TestRequest['flush']>[0];
interface RequestOptions {
    params?: Record<string, string>;
    headers?: Record<string, string>;
}
/**
 * This convenience function is similar to {@linkcode https://angular.dev/api/common/http/testing/HttpTestingController | HttpTestingController.expectOne()}, with extra features. The returned request object will automatically trigger change detection when you flush a response, just like in production.
 *
 * This function is opinionated in that you must specify all aspects of the request to match. E.g. if the request specifies headers, you must also specify them in the arguments to this method.
 *
 * This function only works when you are using an {@linkcode AngularContext}.
 *
 * ```ts
 * const ctx = new AngularContext({ providers: [provideHttpClient()] });
 * ctx.run(() => {
 *   inject(HttpClient)
 *     .get('http://example.com', { params: { key: 'value' } })
 *     .subscribe();
 *   const request = expectRequest<string>('GET', 'http://example.com', {
 *     params: { key: 'value' },
 *   });
 *   request.flush('my response body');
 * });
 * ```
 */
export declare function expectRequest<ResponseBody extends HttpBody>(method: HttpMethod, url: string, options?: RequestOptions & {
    body?: HttpBody;
}): SlTestRequest<ResponseBody>;
export {};
